from u3driver.commands.ObjectCommands.get_text import *
from u3driver.commands.ObjectCommands.get_text import *
from u3driver.commands.ObjectCommands.tap import *
from u3driver.commands.ObjectCommands.drag import *